==> gitlab-foss-v17.10.4.tar.bz2: gitlab-foss-v17.10.4/app/graphql/resolvers/ci/catalog/resources_resolver.rb <==
# frozen_string_literal: true

module Resolvers
  module Ci
    module Catalog
      class ResourcesResolver < BaseResolver
        include LooksAhead

        type ::Types::Ci::Catalog::ResourceType.connection_type, null: true

        argument :scope, ::Types::Ci::Catalog::ResourceScopeEnum,
          required: false,
          default_value: :all,
          description: 'Scope of the returned catalog resources.'

        argument :search, GraphQL::Types::String,
          required: false,
          description: 'Search term to filter the catalog resources by name or description.'

        argument :sort, ::Types::Ci::Catalog::ResourceSortEnum,
          required: false,
          description: 'Sort catalog resources by given criteria.'

        argument :verification_level, ::Types::Ci::Catalog::Resources::VerificationLevelEnum,
          required: false,
          description: 'Filter catalog resources by verification level.'

        def resolve_with_lookahead(scope:, search: nil, sort: nil, verification_level: nil)
          apply_lookahead(
            ::Ci::Catalog::Listing
              .new(context[:current_user])
              .resources(sort: sort, search: search, scope: scope, verification_level: verification_level)
          )
        end

        private

        def preloads
          {
            full_path: { project: [:route, { namespace: :route }] },
            web_path: { project: { namespace: :route } },
            readme_html: { project: :route }
          }
        end
      end
    end
  end
end

==> gitlab-foss-v18.7.0.tar.bz2: gitlab-foss-v18.7.0/app/graphql/resolvers/ci/catalog/resources_resolver.rb <==
# frozen_string_literal: true

module Resolvers
  module Ci
    module Catalog
      class ResourcesResolver < BaseResolver
        include LooksAhead

        type ::Types::Ci::Catalog::ResourceType.connection_type, null: true

        argument :scope, ::Types::Ci::Catalog::ResourceScopeEnum,
          required: false,
          default_value: :all,
          description: 'Scope of the returned catalog resources.'

        argument :search, GraphQL::Types::String,
          required: false,
          description: 'Search term to filter the catalog resources by name or description.'

        argument :sort, ::Types::Ci::Catalog::ResourceSortEnum,
          required: false,
          description: 'Sort catalog resources by given criteria.'

        argument :verification_level, ::Types::Namespaces::VerificationLevelEnum,
          required: false,
          description: 'Filter catalog resources by verification level.'

        argument :topics, [GraphQL::Types::String],
          required: false,
          description: 'Filter catalog resources by project topic names.'

        def resolve_with_lookahead(scope:, search: nil, sort: nil, verification_level: nil, topics: nil)
          apply_lookahead(
            ::Ci::Catalog::Listing
              .new(context[:current_user])
              .resources(
                sort: sort,
                search: search,
                scope: scope,
                verification_level: verification_level,
                topics: topics
              )
          )
        end

        private

        def preloads
          {
            full_path: { project: [:route, { namespace: :route }] },
            web_path: { project: { namespace: :route } },
            readme_html: { project: :route },
            archived: { project: { namespace: [:namespace_settings,
              :namespace_settings_with_ancestors_inherited_settings] } },
            versions: { versions: :components }
          }
        end
      end
    end
  end
end
